@@ -42,6 +42,7 @@ def update():
                               resolve=cluster_create.trans_mount)
     cmd_update_cluster.option("-i, --image [imageId]", MSG['update_cluster']['option']['image'],
                               resolve=cluster_update.trans_image)
+    cmd_update_cluster.option("-t, --type [instanceType]", MSG['update_cluster']['option']['type'])
     cmd_update_cluster.option("-u, --user_data [kv_pairs]",
                               MSG['update_cluster']['option']['user_data'],
                               resolve=cluster_update.trans_user_data)
@@ -127,7 +128,12 @@ def create():
 
     cmd_create_cluster.option("--vpc_cidr_block [vpc_cidr_block]",
                               MSG['create_cluster']['option']['vpc_cidr_block'])
-    cmd_create_cluster.option("-f, --filePath [filePath]", MSG['create_cluster']['option']['filePath'],
+    cmd_create_cluster.option("--vpc_id [vpc_id]",
+                              MSG['create_cluster']['option']['vpc_id'])
+    cmd_create_cluster.option("-f, --file_path [file_path]", MSG['create_cluster']['option']['file_path'],
+                              visible=IS_GOD)
+    cmd_create_cluster.option("--schedule_type [schedule_type]", MSG['create_cluster']['option']['schedule_type'],
+                              resolve=cluster_create.trans_schedule_type,
                               visible=IS_GOD)
     cmd_create_cluster.option("--show_json",
                               MSG['create_cluster']['option']['show_json'])
