@@ -269,7 +269,7 @@ def __get_json():
     **********************************************
                 ''',
                 'inputs': '''如果后缀为//:oss, 表示自动生成oss路径,
-                                             如果是文件则自动上传到oss相应的路径下, 如: --iWDL hello.wdl//:oss''',
+                                             如果是文件则自动上传到oss相应的路径下, 如: --iWDL echo.wdl//:oss''',
                 'outputs': '''如果后缀为//:oss, 表示自动生成oss路径,  如: --iWDL ./demo///:oss'''
             }
         },
